# QTAF 

[![Build Status](https://travis-ci.org/Tencent/QTAF.svg?branch=master)](https://travis-ci.org/Tencent/QTAF) 
[![PyPi version](https://img.shields.io/pypi/v/qtaf.svg)](https://pypi.python.org/pypi/qtaf/) 
[![GitHub tag](https://img.shields.io/github/tag/Tencent/QTAF.svg)](https://GitHub.com/Tencent/QTAF/tags/)

QTA is a cross-platform test automation tool for servers and native, hybrid and applications.

### Supported Platforms

* iOS (powered by [QT4i](https://github.com/tencent/QT4i) driver)
* Android (powered by [QT4A](https://github.com/tencent/QT4A) driver)
* Web (powered by [QT4W](https://github.com/qtacore/QT4W) driver)
* Windows (powered by QT4C driver)
* macOS (powered by QT4Mac driver))
* Server (powered by QT4S driver)

QTAF (QTA Framework) is a base framework for QTA, including,

* testbase
* tuia

### Testbase

Testbase is a test framework providing test execution, reporting and management, and is the common base for each platform-specific QTA driver.

For more inforamtion about quick startup, usage and API reference, please read [testbase's document](http://qta-testbase.readthedocs.io/zh/latest/).


### TUIA

TUIA (Tencent UI Automation) is a base framework for UI test automation, which is used by each platform-specific QTA driver for client.

For more inforamtion about quick startup, usage and API reference, please read [TUIA's document](http://qta-tuia.readthedocs.io/zh/latest/).


------------------------------

QTA是一个跨平台的测试自动化工具，适用于后台、原生或混合型客户端应用的测试。

### 平台支持

* iOS (由[QT4i](https://github.com/tencent/QT4i) driver提供)
* Android (由[QT4A](https://github.com/tencent/QT4A) driver提供)
* Web (由[QT4W](https://github.com/qtacore/QT4W) driver提供)
* Windows (由QT4C driver提供)
* macOS (由QT4Mac driver提供)
* Server (由QT4S driver提供)


QTAF (QTA Framework)是QTA的基础框架，包括以下模块：

* testbase
* tuia

### Testbase

Testbase是测试框架基础，提供包括测试执行、报告和用例管理等基础功能。Testbase会被各个平台的QTA Driver所使用。

快速入门、使用和接口文档请参考《[Testbase文档](http://qta-testbase.readthedocs.io/zh/latest/)》。


### TUIA

TUIA (Tencent UI Automation)是UI自动化基础库，为QTA各个平台下的客户端UI测试Driver所使用。

快速入门、使用和接口文档请参考《[TUIA文档](http://qta-tuia.readthedocs.io/zh/latest/index.html)》。

------------------------------

欢迎加入QQ群（432699528）交流使用和反馈

![image](https://github.com/Tencent/QTAF/blob/master/docs/misc/qq_group.png)
